from typing import Tuple

def hex2rgb(hex_code: str) -> Tuple[int, int, int]:
    """Converts a given hex string to RGB color code format."""
    
    if hex_code.startswith("#"):
        hex_code = hex_code[1:]

    if not (len(hex_code) == 3 or len(hex_code) == 6):
        raise ValueError("Hex code length should be either 3 or 6")

    if len(hex_code) == 3:
        hex_code = ''.join([c * 2 for c in hex_code])

    red = int(hex_code[0:2], 16)
    green = int(hex_code[2:4], 16)
    blue = int(hex_code[4:6], 16)

    return (red, green, blue)


def rgb2hex(rgb: list[int]) -> str:
    return f"#{''.join(f'{x:02x}' for x in rgb)}"



from setuptools import setup, find_packages

setup(
    name='rgb2hex',
    version='0.1.0.dev1024',
    author='Web Tech Moz',
    author_email='zoidycine@gmail.com',
    description='A simple Python library for converting between Hexadecimal and RGB color formats',
    long_description=open('README.md', 'r', encoding='UTF-8').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/webtechmoz/rgb2hex.git',
    packages=find_packages(),
    keywords=['hex2rgb', 'rgb2hex', 'rgbtohexadecimal', 'hex-to-rgb', 'rgbhex'],
    license='MIT',
    classifiers=[
        'Programming Language :: Python :: 3.10',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.10',
)